from distutils.core import setup

setup(
    name="confik",
    version="1.0.5",
    description="Config parser for environment variables",
    author="LeOndaz",
    author_email="ahmeddark369@gmail.com",
    url="https://github.com/LeOndaz/confik",
    packages=["confik"],
)
